/*
 * #%L
 * Aquarium-Manager-Persistence
 * %%
 * Copyright (C) 2012 Aquarium-Manager-Gruppe
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
package test.config;

import com.objectdb.jpa.Provider;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.ImportResource;
import org.springframework.dao.support.PersistenceExceptionTranslator;
import org.springframework.instrument.classloading.InstrumentationLoadTimeWeaver;
import org.springframework.orm.jpa.DefaultJpaDialect;
import org.springframework.orm.jpa.JpaTransactionManager;
import org.springframework.orm.jpa.LocalContainerEntityManagerFactoryBean;
import org.springframework.transaction.annotation.EnableTransactionManagement;
import test.entities.AbstractPersistable;

import javax.persistence.EntityManagerFactory;

@Configuration
@EnableTransactionManagement
@ImportResource("classpath:test/spring/spring-data-config.xml")
@ComponentScan("test")
public class SystemConfiguration {
    @Bean
    public JpaTransactionManager transactionManager() {
        final EntityManagerFactory emf = factoryBean();
        return new JpaTransactionManager(emf);
    }

    @Bean
    public PersistenceExceptionTranslator translator() {
        return new DefaultJpaDialect();
    }

    @Bean
    public EntityManagerFactory factoryBean() {
        final LocalContainerEntityManagerFactoryBean emfb = new LocalContainerEntityManagerFactoryBean();
        emfb.setLoadTimeWeaver(new InstrumentationLoadTimeWeaver());
        emfb.setPersistenceUnitName("$objectdb/test.odb"); //NON-NLS
        emfb.setPersistenceProvider(new Provider());
        emfb.setPackagesToScan(AbstractPersistable.class.getPackage().getName());
        emfb.afterPropertiesSet();
        return emfb.getObject();
    }
}
